#ifndef darksidecore_Data_FragmentType_hh
#define darksidecore_Data_FragmentType_hh
#include "artdaq-core/Data/Fragment.hh"

namespace ds50
{
	/**
	 * \brief List of names (in the order defined below) of the User types defined in darksidecore
	 */
        std::vector<std::string> const names{"MISSED", "V1495", "V1720", "V1724", "V1190", "V1495Veto", "UNKNOWN"};

	/**
	 * \brief Implementation details namespace
	 */
	namespace detail
	{
		/**
		 * \brief User type codes defined by darksidecore
		 */
		enum FragmentType : artdaq::Fragment::type_t
		{
			MISSED = artdaq::Fragment::FirstUserFragmentType,
			V1495,
			V1720,
			V1724,
			V1190,
			V1495Veto,
			INVALID // Should always be last.
		};

		// Safety check.
		static_assert(artdaq::Fragment::isUserFragmentType(FragmentType::INVALID - 1),
			"Too many user-defined fragments!");
	}

	using detail::FragmentType;

	/**
	 * \brief Lookup the type code for a fragment by its string name
	 * \param t_string Name of the Fragment type to lookup
	 * \return artdaq::Fragment::type_t corresponding to string, or INVALID if not found
	 */
	FragmentType toFragmentType(std::string t_string);

	/**
	 * \brief Look up the name of the given FragmentType
	 * \param val FragmentType to look up
	 * \return Name of the given type (from the names vector)
	 */
	std::string fragmentTypeToString(FragmentType val);
}
#endif /* darksidecore_Data_FragmentType_hh */
